# emilrex

<p align="center">
    <a href="https://pypi.python.org/pypi/emilrex/" alt="PyPI version">
        <img alt="PyPI" src="https://img.shields.io/pypi/v/emilrex"></a>
    <a href="https://github.com/EmilRex/emilrex-py/" alt="Stars">
        <img src="https://img.shields.io/github/stars/EmilRex/emilrex-py" /></a>
    <a href="https://pepy.tech/badge/emilrex/" alt="Downloads">
        <img src="https://img.shields.io/pypi/dm/emilrex" /></a>
    <a href="https://github.com/EmilRex/emilrex-py/pulse" alt="Activity">
        <img src="https://img.shields.io/github/commit-activity/m/EmilRex/emilrex-py" /></a>
    <br>
</p>

Personal Python package.

## Getting Started

```sh
pip install -U emilrex

emilrex --help
```
